<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_a1e707d02a236dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWNobWVudC1jb3V" . "udA=="), "_f5894760" . "07fa133f4" . "57c3ef29d" . "dfa566" => base64_decode("VG8" . "="), "_d706c160e45bf7434fff82a59" . "76f0e19" => base64_decode("YXJyYXl" . "fa2V5cw" . "=="), "_1d6c68a0262e8fa0bed1215" . "b7224a98e" => base64_decode("cmVj" . "aXBp" . "ZW50"), "_956cd32298a" . "229f9768f109" . "6f077ace3" => base64_decode("Ym9keS1wbGF" . "pbg=="), "_8c575917" . "cbaedf1e7" . "efae84939" . "402bff" => base64_decode("U3ViamVjd" . "A=="), "_9c050c786fc871" . "70cbb84fc6a8b13" . "cb6" => base64_decode("YXR0YWNo" . "bWVudC0="), "_f39f5346e313e4dd1ac3" . "a7bd8032beda" => base64_decode("c3Vic3RyX2Nvb" . "XBhcmU="), "_44e986c04f41a" . "08b56a383c7b3a" . "88ee2" => base64_decode("c2" . "Vu" . "ZG" . "Vy"), "_97ea09a7faf27c52c6eff6" . "9773df1d8a" => base64_decode("dGltZXN0YW1" . "w"), "_618a4aeb9fe" . "cc4592a4521f" . "34876fa29" => base64_decode("ZnJvbQ" . "=="), "_6e1c717cf3cbf1af98" . "2ed74d4336b7f1" => base64_decode("Ym9keS1od" . "G1s"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_d706c160" . "e45bf7434" . "fff82a597" . "6f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a1e707d02a236dadebd15a" . "45e65ebdb6"] && $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_f39f5346e313" . "e4dd1ac3a7bd8" . "032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_9c050c786fc87170cbb8" . "4fc6a8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_1d6c68a0262e8fa0b" . "ed1215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_618a4aeb9fecc45" . "92a4521f34876fa2" . "9"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_8c575917cbaedf1e7efae" . "84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_6e1c717cf3cbf1af982ed74d" . "4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_956cd32298a229f9768f1096f077ac" . "e3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_97ea09a7f" . "af27c52c6e" . "ff69773df1" . "d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_44e986c04f41a08b56a383c7b3a" . "88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}