<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array("_03b1f0cee835582d1158dce2678" . "b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJzY3JpY" . "mVy"), "_a3d82c5df38e194c9c73e3ccb422" . "3bbc" => base64_decode("ZW1haW" . "xfZGF0" . "YQ=="), "_5d40a2cf1c525fb252bf5599" . "e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlb" . "nRpZmllZCBmb3IgbWFpbDsgc3ViamVjdCAn"), "_460e1aeb3113a16" . "76ce59a8f40431d5" . "c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0d" . "XJlIHByb2plY3Q="), "_c35473364fa7a050299058f332ec2" . "9c1" => base64_decode("ZXhjZXB0a" . "W9u"), "_9b16fa2683095e67d7c8b265" . "a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRX" . "ZlbnRSZWNlaXZlcg=="), "_67a0d624aebcceb0a" . "bd5ce56a53ff06f" => base64_decode("ZG" . "F0" . "ZQ" . "=="), "_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128" => base64_decode("Ym9keV9" . "0ZXh0"), "pro" . "jec" . "t_i" . "d" => base64_decode("cHJvamVjdF" . "9pZA=="), "_bfda889b74ea561b14325e30e7d7542" . "6" => base64_decode("Ym9k" . "eV9o" . "dG1s"), "_f656816961e85738" . "06141c558b184fe2" => base64_decode("c3ViamVjdA=" . "="), "_618a4aeb9fecc4592a" . "4521f34876fa29" => base64_decode("ZnJvbQ" . "=="), "_e608e5b5c4c34a67ba97ef84c1e16" . "199" => base64_decode("Jw=" . "="), "_376d30c40857357a4d4cbb1ffaa" . "25817" => base64_decode("dG8" . "="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_9b16fa268" . "3095e67d7c" . "8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_03b1f0cee835582d1" . "158dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_5d40a2cf1" . "c525fb252b" . "f5599e339f" . "dd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_e608e5b5c4c34a67b" . "a97ef84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4521f34876fa" . "29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_376d30c40857357a4" . "d4cbb1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_f656816961e8573806141c558b184f" . "e2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_bfda889b74ea561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_67a0d624aebcceb0abd" . "5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_460e1aeb3113a1676ce59a8f404" . "31d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_a3d82c5df38e194c9c73e3ccb" . "4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_c35473364fa7a050299058" . "f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}